All of the people who have made at least one contribution to datamol.
Authors are sorted alphabetically.

* DeepSource Bot
* Emmanuel Noutahi
* Hadrien Mary
* Honoré Hounwanou
* Ishan Kumar
* Julien Horwood
* Therence1
* deepsource-autofix[bot]
* michelml
* mike
